@@ -6,7 +6,7 @@ no warnings qw(void once uninitialized numeric);
 package Moops;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.033';
+our $VERSION   = '0.034';
 
 use Exporter::Tiny qw(mkopt);
 use Keyword::Simple qw();
@@ -225,6 +225,28 @@ Unstable.
 Until version 1.000, stuff might change, but not without good
 reason.
 
+=head2 Planned Changes
+
+=over
+
+=item *
+
+Support for using Function::Parameters to handle method signatures
+is likely to be dropped.
+
+=item *
+
+Parameterized class and parameterized role support is planned.
+
+=item *
+
+The internals for parsing C<class>, C<role>, C<namespace>, and C<library>
+may change to use L<Parse::Keyword> rather than L<Keyword::Simple>. This
+will likely break any extensions that rely on subclassing or adding traits
+to the L<Moops::Parser> or L<Moops::Keyword> classes.
+
+=back
+
 =head1 DESCRIPTION
 
 Moops is sugar for declaring and using roles and classes in Perl.
@@ -336,7 +358,7 @@ use a trailing semicolon.
 
 If using Moose or Mouse, classes are automatically made immutable. 
 
-L<namespace::sweep> is automatically used in all classes.
+L<namespace::autoclean> is automatically used in all classes.
 
 Between the class declaration and its body, L<Attribute::Handlers>-style
 attributes may be provided:
@@ -357,7 +379,7 @@ C<< :assertions >> - enables assertion checking (see below)
 
 =item *
 
-C<< :dirty >> - suppresses namespace::sweep
+C<< :dirty >> - suppresses namespace::autoclean
 
 =item *
 
@@ -402,7 +424,7 @@ roles.)
 
 If roles use Moo, the L<MooX::late> extension is enabled.
 
-L<namespace::sweep> is automatically used in all roles.
+L<namespace::autoclean> is automatically used in all roles.
 
 Roles take similar L<Attribute::Handlers>-style attributes to
 classes, but don't support C<< :mutable >>.
@@ -438,7 +460,7 @@ any class-specific or role-specific semantics.
       # ...
    }
 
-L<namespace::sweep> is not automatically used in namespaces.
+L<namespace::autoclean> is not automatically used in namespaces.
 
 L<Attribute::Handlers>-style attributes are supported for namespaces,
 but most of the built-in attributes make any sense without class/role
@@ -617,7 +639,7 @@ problem of using L<MooseX::Types> type libraries in L<Moo> classes:
 =head2 Constants
 
 The useful constants C<true> and C<false> are imported into all declared
-packages. (Within classes and roles, namespace::sweep will later remove
+packages. (Within classes and roles, namespace::autoclean will later remove
 them from the symbol table, so they don't form part of your package's API.)
 These constants can help make attribute declarations more readable.
 
@@ -630,7 +652,7 @@ L<PerlX::Define>):
       define PI = 3.2;
    }
 
-Constants declared this way will I<not> be swept away by namespace::sweep,
+Constants declared this way will I<not> be swept away by namespace::autoclean,
 and are considered part of your package's API.
 
 =head2 Assertions
@@ -824,8 +846,16 @@ L<http://rt.cpan.org/Dist/Display.html?Queue=Moops>.
 B<< IRC: >> support is available through in the I<< #moops >> channel
 on L<irc.perl.org|http://www.irc.perl.org/channels.html>.
 
-For anything Moo-specific, you may have better luck in the
-I<< #web-simple >> channel; or for Moose-specific queries, I<< #moose >>.
+For general Moose/Moo queries which don't seem to be related to Moops'
+syntactic sugar, your question may be answered more quickly in the
+I<< #moose >> channel.
+
+B<< Web: >> if you ask a question on PerlMonks in
+L<Seekers of Perl Wisdom|http://www.perlmonks.org/?node_id=479> with
+"Moops" in the subject line, it should be answered pretty quickly.
+
+There is a L<moops tag|http://stackoverflow.com/questions/tagged/moops>
+on StackOverflow.
 
 =head1 SEE ALSO
 
@@ -835,10 +865,10 @@ L<https://github.com/stevan/p5-mop-redux>.
 
 Main functionality exposed by this module:
 L<Moo>/L<MooX::late>, L<Kavorka>, L<Try::Tiny>, L<Types::Standard>,
-L<namespace::sweep>, L<true>.
+L<namespace::autoclean>, L<true>, L<PerlX::Assert>.
 
 Internals fueled by:
-L<Keyword::Simple>, L<Module::Runtime>, L<Import::Into>, L<Devel::Pragma>,
+L<Keyword::Simple>, L<Module::Runtime>, L<Import::Into>,
 L<Attribute::Handlers>.
 
 L<http://en.wikipedia.org/wiki/The_Bubble_Boy_(Seinfeld)>.
